#
# spec file for package rage-encryption
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!rust_tier1_arches:%global rust_tier1_arches x86_64 aarch64}

Name:           rage-encryption
#               This will be set by osc services, that will run after this.
Version:        0.9.0+0
Release:        150500.1.21
Summary:        Simple, modern, and secure file encryption tool
#               If you know the license, put it's SPDX string here.
#               Alternately, you can use cargo lock2rpmprovides to help generate this.
License:        (0BSD OR MIT OR Apache-2.0) AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR MIT OR Zlib) AND (MIT OR Unlicense) AND (Apache-2.0 OR Zlib OR MIT) AND Apache-2.0 AND BSD-3-Clause AND CDDL-1.0 AND MIT
#               Select a group from this link:
#               https://en.opensuse.org/openSUSE:Package_group_guidelines
Group:          Productivity/Security
URL:            https://github.com/str4d/rage
Source0:        rage-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        cargo_config
%if %{suse_version} > 1500
BuildRequires:  cargo-packaging
%endif
# Requires >1.59 for thread::available_parallelism
BuildRequires:  cargo >= 1.59
BuildRequires:  vendored_licenses_packager
# for feature mount
BuildRequires:  fuse-devel
Recommends:     pinentry
Conflicts:      rage
ExclusiveArch:  %{rust_tier1_arches}

%description
Rage is a simple, modern, and secure file encryption tool, using the age format. It features small
explicit keys, no config options, and UNIX-style composability.

%package bash-completion
Summary:        Bash completion for %{name}
Group:          Productivity/Security
BuildArch:      noarch
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
Conflicts:      rage

%description bash-completion
Bash command line completion support for %{name}

%prep
%setup -q -a 0 -n rage-%{version}
%setup -q -n rage-%{version} -a 1 -D -T
mkdir .cargo
cp %{SOURCE2} .cargo/config
%vendored_licenses_packager_prep

%build
%define build_args --manifest-path rage/Cargo.toml --features "mount" --release %{?_smp_mflags}

%if %{suse_version} > 1500
%{cargo_build} --features "mount"
%else
cargo build %{build_args}
%endif

cargo run --example generate-completions %{build_args}
cargo run --example generate-docs %{build_args}

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/rage-%{version}/target/release/rage %{buildroot}%{_bindir}/rage
install -m 0755 %{_builddir}/rage-%{version}/target/release/rage-keygen %{buildroot}%{_bindir}/rage-keygen
install -m 0755 %{_builddir}/rage-%{version}/target/release/rage-keygen %{buildroot}%{_bindir}/rage-mount

for i in "" -keygen -mount; do
  install -D -p -m 644 target/manpages/rage$i.1.gz %{buildroot}/%{_mandir}/man1/rage$i.1%{?ext_man}
  install -D -p -m 644 target/completions/rage$i.bash %{buildroot}%{_datadir}/bash-completion/completions/rage$i
done
%vendored_licenses_packager_install

%files
%{_bindir}/rage
%{_bindir}/rage-keygen
%{_bindir}/rage-mount
%doc README.md rage/CHANGELOG.md
# accept duplicates here
%license LICENSE-APACHE LICENSE-MIT
%vendored_licenses_packager_files
%{_mandir}/man1/rage*.1%{?ext_man}

%files bash-completion
%license LICENSE-APACHE LICENSE-MIT
%{_datadir}/bash-completion/completions/rage*

%changelog
* Fri Jan 13 2023 william.brown@suse.com
- bsc#1207039 - CVE-2023-22895 - update bzip2 crate
- Update of vendored dependencies
* Thu Jan  5 2023 william.brown@suse.com
- Update of vendored dependencies
* Mon Nov 21 2022 dimstar@opensuse.org
- Do not have the main package recommend the bash-completion
  sub-package, but rather have the subpackage supplement the
  combination of tage-encryption and bash-completion.
* Mon Oct 31 2022 william.brown@suse.com
- Update to version 0.9.0+0:
  * v0.9.0
  * use pkcs1 crate to parse RSAPrivateKey ASN.1 object
  * qa: Add workflow that runs `cargo vet --locked`
  * qa: Import `cargo vet` audits from Firefox and zcashd
  * qa: Add `crypto-reviewed` criteria or `cargo vet`
  * qa: `cargo vet init`
* Tue Aug  9 2022 william.brown@suse.com
- Set minimum rust requirement to 1.59
- Update to version 0.8.1+0:
  * v0.8.1
  * Revert updates to `dashmap` and `indexmap`
  * cargo update
  * age: Add passphrase to scrypt_work_factor_23 testkit test file
  * age: Reject invalid or non-canonical X25519 recipient stanzas
  * age: Require "contributory" behaviour for X25519 recipient stanzas
  * age: Add testkit test files from reference impl
  * Update Homebrew formula to v0.8.0
* Tue May  3 2022 william.brown@suse.com
- Update to version 0.8.0+0:
  * v0.8.0
  * age: Allow ciphertexts that encrypt the empty plaintext
  * Update Italian translation
  * Don't allow -i/--identity with passphrase-encrypted files
  * age: Require the last STREAM chunk to be non-empty
  * age: Return correct response encoding for `confirm` command
  * age: Base64-decode metadata arguments to "confirm" message
  * age: Extract "confirm" command handling into a helper function
* Tue Apr  5 2022 william.brown@suse.com
- Automatic update of vendored dependencies
* Mon Mar 14 2022 william.brown@suse.com
- Update to resolve bsc#1196972 CVE-2022-24713 - Regex DOS
* Mon Mar 14 2022 cunix@mail.de
- switched to vendored_licenses_packager as build dependency
- define macro "rust_tier1_arches" if undefined
* Tue Feb 15 2022 william.brown@suse.com
- Add specific lock file path to _service for cargo audit to prevent
  confusion with the lock files in the fuzz folders.
* Mon Jan 31 2022 cunix@mail.de
- Update to version 0.7.1
  * Fixed a bug where non-canonical recipient stanza bodies in an age
    file header would cause rage to crash instead of being rejected
  * vendor.tar.xz updated from source code Cargo.lock file
- Added:
  * binary rage-mount
  * bash-completion for rage, rage-keygen and rage-mount
  * manual pages for rage, rage-keygen and rage-mount
  * Licenses files
  * Licenses files of vendored crates extracted
    with script "vendored_licenses_packager.sh"
  * README and CHANGELOG files
  * possibility to build without cargo-packaging for "older" distros
* Fri Nov 19 2021 william.brown@suse.com
- Update to version 0.7.0~git0.c93b914:
  * v0.7.0
  * cargo update fuzz*
  * Update lockfiles for fuzzers
  * rage: Pin clap to 3.0.0-beta.2
  * CI: Add bitrot check to ensure examples and benchmarks still compile
  * console 0.15
  * age: Re-export `secrecy` crate
  * age-core: Improve crate documentation
  * age-core: Re-export `secrecy` crate
  * age-core: Add `plugin::Error` enum
* Tue Nov 16 2021 william.brown@suse.com
- Initial commit of rage
